{% if is_namespace %}
    # this is a namespace package
    from __future__ import absolute_import

    try:
        import pkg_resources
        pkg_resources.declare_namespace(__name__)
    except ImportError:
        import pkgutil
        __path__ = pkgutil.extend_path(__path__, __name__)
{% else %}
    from __future__ import absolute_import, print_function, unicode_literals
{% endif %}
