# coding: utf-8

from __future__ import absolute_import, print_function, unicode_literals

DEFAULT_FEATURES = {
    'git',
    'make',
    'pytest',
    'python',
    'pylint',
}

DEFAULT_FILES = {
    'requirements',
    'requirements-dev',
    'classifiers',
    'version',
}
