# This file is autogenerated by edgy.project code generator.
# All changes will be overwritten.

from setuptools import setup, find_packages

tolines = lambda c: list(filter(None, map(lambda s: s.strip(), c.split('\n'))))

def read(filename, flt=None):
    with open(filename) as f:
        content = f.read().strip()
        return flt(content) if callable(flt) else content

version = read('version.txt')

setup(
    {% for k, v in setup.items() -%}
        {{ k }} = {{ v | pprint }},{{ '\n    ' }}
    {%- endfor -%}
    version = version,
    long_description = read('README.rst'),
    classifiers = read('classifiers.txt', tolines),
    packages = find_packages(exclude=['ez_setup', 'example', 'test']),
    include_package_data = True,
    {% if install_requires -%}
        install_requires = {{ install_requires | pprint }},{{ '\n    ' }}
    {%- endif -%}
    {% if extras_require -%}
        extras_require = {{ extras_require | pprint }},{{ '\n    ' }}
    {%- endif -%}
    {% if entry_points -%}
        entry_points = {{ entry_points | pprint }},{{ '\n    ' }}
    {%- endif -%}
    url = {{ url | pprint }},
    download_url = {{ download_url | pprint }}.format(version=version),
)
